@@ -29,11 +29,11 @@ import (
 
 	addonv1alpha1 "github.com/open-cluster-management/api/addon/v1alpha1"
 	workv1 "github.com/open-cluster-management/api/work/v1"
-	appsv1 "github.com/open-cluster-management/multicloud-operators-placementrule/pkg/apis/apps/v1"
-	mcov1beta1 "github.com/open-cluster-management/multicluster-monitoring-operator/pkg/apis/observability/v1beta1"
-	"github.com/open-cluster-management/multicluster-monitoring-operator/pkg/config"
-	"github.com/open-cluster-management/multicluster-monitoring-operator/pkg/controller/multiclusterobservability"
-	"github.com/open-cluster-management/multicluster-monitoring-operator/pkg/util"
+	appsv1 "github.com/stolostron/multicloud-operators-placementrule/pkg/apis/apps/v1"
+	mcov1beta1 "github.com/stolostron/multicluster-monitoring-operator/pkg/apis/observability/v1beta1"
+	"github.com/stolostron/multicluster-monitoring-operator/pkg/config"
+	"github.com/stolostron/multicluster-monitoring-operator/pkg/controller/multiclusterobservability"
+	"github.com/stolostron/multicluster-monitoring-operator/pkg/util"
 )
 
 const (
@@ -236,6 +236,11 @@ func (r *ReconcilePlacementRule) Reconcile(request reconcile.Request) (reconcile
 		return reconcile.Result{}, nil
 	}
 
+	if !deleteAll && mco.Spec.ObservabilityAddonSpec != nil && !mco.Spec.ObservabilityAddonSpec.EnableMetrics {
+		reqLogger.Info("EnableMetrics is set to false. Delete Observability addons")
+		deleteAll = true
+	}
+
 	//read image manifest configmap to be used to replace the image for each component.
 	if _, err = config.ReadImageManifestConfigMap(r.client); err != nil {
 		return reconcile.Result{}, err
